/*
 * LCD_16x2_thermometer
 * ADC-vel megméri az A4 analóg bemenetre analóg hőmérő jelét, 
 * átszámítja fokokra, s az eredményt kiirja az LCD kijelzőre. 
 * Kapcsoljuk egy MCP9700 hőmérő kimenetét az A4 (P1_4) bemenetre, 
 * két további kivezetését pedig a földre (GND) és a tápfeszültségre (VCC)!
 *
 * Kijelzésre a 16x2 LCD ipari szabvány kijelzőt használjuk.
 * A LiquidCrystal programkönyvtár minden olyan LCD kijelzővel
 * kompatibilis, amelyik a Hitachi HD44780 vagy azzal kompatibilis
 * vezérlő IC-t használ.
 *
 * Hardver követelmények:
 *  - Launchpad kártya MSP430G2553 vagy MSP430G2452 mikrovezérlővel
 *  - HD44780 kompatibilis 16x2 karakteres LCD kijelző
 *  - Potméter vagy más analóg jelforrás az A4 bemenetre kötve 
 *    (0- 3,5 V közötti feszültség legyen!) 
 *
 * Bekötési vázlat
 * LCD kivezetés      Launchpad
 * ---------------------------------
 * 01 - GND             GND, potméter
 * 02 - VCC             +5V, potméter
 * 03 - Kontraszt       GND vagy Pot csúszka
 * 04 - RS              Pin8 (P2.0)
 * 05 - R/W             GND
 * 06 - EN              Pin9 (P2.1)
 * 07 - DB0             GND vagy NC
 * 08 - DB1             GND vagy NC
 * 09 - DB2             GND vagy NC
 * 10 - DB3             GND vagy NC
 * 11 - DB4             Pin10 (P2.2)
 * 12 - DB5             Pin11 (P2.3)
 * 13 - DB6             Pin12 (P2.4)
 * 14 - DB7             Pin13 (P2.5)
 * 15 - LED anód        +3,5V
 * 16 - LED katód       GND
 *
 */

#include <LiquidCrystal.h>       //Becsatoljuk a programkönyvtárat

long mysum;                      //ebben összegezzük az eredményt
//Inicializáljuk a programkönyvtárat az alábbi lábkiosztással
LiquidCrystal lcd(P2_0, P2_1, P2_2, P2_3, P2_4, P2_5);

void setup() {
  analogReference(INTERNAL1V5);  //Az 1,5 V-os belső referenciát választjuk 
  lcd.begin(16, 2);              //Beállítjuk a sorok és oszlopok számát)
  lcd.print("Thermometer");      //Kiírunk egy szöveget az első sorba
}

void loop() {
   mysum = 0;
   for(int i=0; i<1500; i++) {
      mysum += analogRead (A4);
   }
  // Átszámítjuk millivoltokra
  float voltage = mysum>>10;      //Osztás 1024-gyel
  float tempC = (voltage-500)/10; //Átszámítás fokokra
  lcd.setCursor(0, 1);            //Kurzor a második sor elejére
  lcd.print(voltage,0);           //Kiíratjuk az eredményt           
  lcd.print(" mV "); 
  lcd.print(tempC,1);
  lcd.print(" C"); 
  delay(1000);
}


