/*
 * LCD_5110_DHT22
 * Hőmérséklet és relatív páratartalom mérése DHT22 szenzorral,
 * Nokia 5110 LCD kijelzéssel (hardveres SPI támogatással)
 *
 * Hardver követelmények:
 *  - Launchpad kártya MSP430G2553 mikrovezérlővel
 *  - Nokia 5110 LCD kijelző
 *  - DHT22 szenzor
 *
 * Huzalozási vázlat:
 *
 * DHT szenzor bekötése: 1-VCC, 2-P2.4, 3-NC, 4-GND
 *
 * Nokia 5110(Sparkfun)       MSP430      
 * ---------------------------------
 * 1. VCC     tápfeszültség    VCC  
 * 2. GND     közös pont       GND   
 * 3. SCE     kiválasztó jel   P2.2 
 * 4. RST     RESET            P1.0 
 * 5. D/C     adat/parancs     P2.3  
 * 6. DIN     MOSI adatvonal   P1.7 
 * 7. SCLK    SPI órajel       P1.5 
 * 8. LED     háttérvilágítás  P2.1
 *
 * Nokia 5110 (E-bay)         MSP430      
 * ---------------------------------
 * 1. RST     RESET            P1.0 
 * 2. CE      kiválasztó jel   P2.2 
 * 3. DC      adat/parancs     P2.3  
 * 4. DIN     MOSI adatvonal   P1.7 
 * 5. CLK     SPI órajel       P1.5 
 * 6. VCC     tápfeszültség    VCC  
 * 7. LIGHT   háttérvilágítás  P2.1 (0: on, 1: off)
 * 8. GND     közös pont       GND  
 */

#include "Energia.h"
#include "SPI.h"
#include "LCD_5110_SPI.h"
#include "DHT.h"
#define DHTPIN P2_4
#define DHTTYPE DHT22   // DHT 22  (AM2302)
DHT dht(DHTPIN, DHTTYPE);

LCD_5110_SPI myScreen;
boolean	backlight = false; 
char temp[8] = {' ', ' ', ' ', '.', ' ', 0x7f, 'C', 0x00};
char rhum[8] = {' ', ' ', ' ', '.', ' ', ' ', '%', 0x00};
long lasttime;

void setup() {
    SPI.begin();
    SPI.setClockDivider(SPI_CLOCK_DIV4);
    SPI.setBitOrder(MSBFIRST);
    SPI.setDataMode(SPI_MODE0);     
    myScreen.begin();                      //LCD inicializálás
    myScreen.setBacklight(backlight);      //Háttérvilágítás beállítása
    myScreen.text(0, 0, " DHT22 sensor "); //Kiírás kis karakterekkel  
    myScreen.text(0, 5, "Light off");
    dht.begin();  
    lasttime = millis();
}

void loop() {
    if (myScreen.getButton()) {            //A nyomógomb ki-be kapcsolja a világítást
        backlight = (backlight==0);
        myScreen.setFont(0);
        myScreen.text(0, 5, backlight ? "Light on " : "Light off");        
        myScreen.setBacklight(backlight);
    }
    if((millis()-lasttime) > 2500) {
        lasttime = millis();
        long h = 10*dht.readHumidity();
        long t = 10*dht.readTemperature();
        displayData(t,temp);
        displayData(h,rhum);
        myScreen.setFont(1);
        myScreen.text(0, 1, temp);
        myScreen.text(0, 3, rhum);
    }    
    delay(200);
}

void displayData(long data, char *buffer) {
    buffer[4] = 0x30 + data%10; 
    data /= 10;
    buffer[2] = 0x30 + data%10; 
    data /= 10;
    if(data) {
        buffer[1] = 0x30 + data%10; 
        data /= 10;
    } else { buffer[1] = ' '; }
     if(data) {
        buffer[0] = 0x30 + data%10; 
        data /= 10;
    } else { buffer[0] = ' '; }  
}  
